from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional
from pianosdk.anon.models.user_model import UserModel


class UserInfo(BaseModel):
    user_lang: Optional[str] = None
    is_new_customer: Optional[bool] = None
    user: Optional['UserModel'] = None
    country_code: Optional[str] = None
    postal_code: Optional[str] = None
    tax_support: Optional[str] = None


UserInfo.model_rebuild()



from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional
from pianosdk.publisher.models.resource import Resource
from pianosdk.publisher.models.user import User


class Access(BaseModel):
    access_id: Optional[str] = None
    parent_access_id: Optional[str] = None
    granted: Optional[bool] = None
    revoked: Optional[bool] = None
    resource: Optional['Resource'] = None
    user: Optional['User'] = None
    expire_date: Optional[datetime] = None
    start_date: Optional[datetime] = None
    can_revoke_access: Optional[bool] = None


Access.model_rebuild()



from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional


class PaymentMethod(BaseModel):
    upi_nickname: Optional[str] = None
    upi_color: Optional[str] = None
    upi_number: Optional[str] = None
    upi_expiration_month: Optional[int] = None
    upi_expiration_year: Optional[int] = None
    upi_postal_code: Optional[str] = None
    description: Optional[str] = None
    user_payment_info_id: Optional[str] = None
    state: Optional[str] = None


PaymentMethod.model_rebuild()



from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional
from pianosdk.publisher.models.global_template_filter_sub_item import GlobalTemplateFilterSubItem
from typing import List


class GlobalTemplateFilterItem(BaseModel):
    id: Optional[str] = None
    name: Optional[str] = None
    counter_value: Optional[int] = None
    global_template_filter_sub_items: Optional['List[GlobalTemplateFilterSubItem]'] = None


GlobalTemplateFilterItem.model_rebuild()



from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional


class PeriodLinkCandidate(BaseModel):
    access_period_id: Optional[str] = None
    name: Optional[str] = None
    type: Optional[str] = None
    payment_billing_plan_description: Optional[str] = None
    current_logic_id: Optional[str] = None
    current_logic_name: Optional[str] = None
    removed: Optional[bool] = None


PeriodLinkCandidate.model_rebuild()



from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional


class SalesTaxRateModel(BaseModel):
    charged: Optional[bool] = None
    charge_rate: Optional[float] = None
    state_abbr: Optional[str] = None
    state_id: Optional[str] = None
    state_name: Optional[str] = None


SalesTaxRateModel.model_rebuild()



from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional
from pianosdk.publisher.models.term_change_billing_options import TermChangeBillingOptions
from typing import List


class TermToEligible(BaseModel):
    name: Optional[str] = None
    type: Optional[str] = None
    enabled: Optional[str] = None
    tooltip: Optional[str] = None
    to_term_id: Optional[str] = None
    to_term_name: Optional[str] = None
    to_period_id: Optional[str] = None
    to_period_name: Optional[str] = None
    to_resource_id: Optional[str] = None
    to_resource_name: Optional[str] = None
    to_billing_plan: Optional[str] = None
    collect_address: Optional[bool] = None
    shared_account_count: Optional[int] = None
    available_billing_timings: Optional['List[TermChangeBillingOptions]'] = None
    prorate_restricted: Optional[bool] = None
    to_term_amount: Optional[float] = None
    authorisation_amount: Optional[float] = None
    to_term_amount_display: Optional[str] = None
    to_term_currency: Optional[str] = None
    prorate_amount: Optional[float] = None
    prorate_amount_display: Optional[str] = None
    prorate_refund_amount: Optional[float] = None


TermToEligible.model_rebuild()



from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional
from pianosdk.anon.models.user_info import UserInfo


class TemplateContext(BaseModel):
    user_info: Optional['UserInfo'] = None
    experience_id: Optional[str] = None
    experience_action_id: Optional[str] = None
    experience_execution_id: Optional[str] = None
    template_language: Optional[str] = None


TemplateContext.model_rebuild()



from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional


class InitiateSecureFieldsParams(BaseModel):
    aid: Optional[str] = None
    tracking_id: Optional[str] = None
    authorization_amount: Optional[str] = None
    return_url: Optional[str] = None


InitiateSecureFieldsParams.model_rebuild()



from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional


class TemplateConfig(BaseModel):
    name: Optional[str] = None
    content1_type: Optional[str] = None
    content2_type: Optional[str] = None
    content3_type: Optional[str] = None
    content1_value: Optional[str] = None
    content2_value: Optional[str] = None
    content3_value: Optional[str] = None
    history_list: Optional[str] = None
    template_type: Optional[str] = None
    boilerplate_type: Optional[str] = None


TemplateConfig.model_rebuild()



from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional
from pianosdk.publisher.models.user import User


class UserNote(BaseModel):
    user_note_id: Optional[str] = None
    user: Optional['User'] = None
    content: Optional[str] = None
    type: Optional[str] = None
    create_date: Optional[str] = None
    create_by: Optional['User'] = None
    update_date: Optional[str] = None
    update_by: Optional['User'] = None
    readonly: Optional[bool] = None


UserNote.model_rebuild()



from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional


class RedemptionPage(BaseModel):
    enabled: Optional[bool] = None


RedemptionPage.model_rebuild()



from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional


class LicenseeManager(BaseModel):
    uid: Optional[str] = None
    first_name: Optional[str] = None
    last_name: Optional[str] = None
    personal_name: Optional[str] = None


LicenseeManager.model_rebuild()



from typing import Dict, MutableMapping


class HttpRequest:
    """Information about an HTTP Request including its method, headers,
        parameters, URL, and Basic Auth details
    """

    def __init__(self,
                 http_method: str,
                 query_url: str,
                 headers: Dict = None,
                 query_parameters: Dict = None,
                 parameters: Dict = None,
                 json: Dict = None,
                 files: Dict = None):
        """Constructor for the HttpRequest class
        Args:
            http_method (HttpMethodEnum): The HTTP Method.
            query_url (string): The URL to send the request to.
            headers (dict, optional): The headers for the HTTP Request.
            query_parameters (dict, optional): Query parameters to add in the
                URL.
            parameters (dict, optional): Form or body parameters to be included
                in the body.
            json (dict, optional): Body parameters to be included
                in the body as JSON.
            files (dict, optional): Files to be sent with the request.
        """
        self.http_method = http_method
        self.query_url = query_url
        self.headers = headers or {}
        self.query_parameters = query_parameters or {}
        self.parameters = parameters or {}
        self.json = json or {}
        self.files = files or {}

    def add_header(self, name: str, value: str):
        """ Add a header to the HttpRequest.
        Args:
            name (string): The name of the header.
            value (string): The value of the header.
        """
        self.headers[name] = value

    def add_parameter(self, name: str, value: str):
        """ Add a parameter to the HttpRequest.
        Args:
            name (string): The name of the parameter.
            value (string): The value of the parameter.
        """
        self.parameters[name] = value

    def add_query_parameter(self, name: str, value: str):
        """ Add a query parameter to the HttpRequest.
        Args:
            name (string): The name of the query parameter.
            value (string): The value of the query parameter.
        """
        self.query_parameters[name] = value


class HttpResponse:
    """Information about an HTTP Response including its status code, returned
        headers, and raw body
    """

    def __init__(self,
                 status_code: int,
                 reason_phrase: str,
                 headers: MutableMapping,
                 text: str,
                 request: HttpRequest):
        """Constructor for the HttpResponse class
        Args:
            status_code (int): The response status code.
            reason_phrase (string): The response reason phrase.
            headers (dict): The response headers.
            text (string): The raw body from the server.
            request (HttpRequest): The request that resulted in this response.
        """
        self.status_code = status_code
        self.reason_phrase = reason_phrase
        self.headers = headers
        self.text = text
        self.request = request
        self.request_id = headers.get('x-request-id', None)


class HttpCallBack:
    def on_before_request(self, request: HttpRequest):
        """The controller will call this method before making the HttpRequest.
        """
        raise NotImplementedError("This method has not been implemented.")

    def on_after_response(self, http_response: HttpResponse):
        """The controller will call this method after making the HttpRequest.
        """
        raise NotImplementedError("This method has not been implemented.")



from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional


class UserAudit(BaseModel):
    uid: Optional[str] = None
    action_type: Optional[str] = None
    aid: Optional[str] = None


UserAudit.model_rebuild()



from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional
from pianosdk.anon.models.external_css import ExternalCss
from typing import List


class LightOfferTemplateVersion(BaseModel):
    offer_template_id: Optional[str] = None
    token_type: Optional[str] = None
    version: Optional[int] = None
    type: Optional[str] = None
    content1_type: Optional[str] = None
    content2_type: Optional[str] = None
    content1_value: Optional[str] = None
    content2_value: Optional[str] = None
    template_id: Optional[str] = None
    template_version_id: Optional[str] = None
    is_offer_template_archived: Optional[bool] = None
    is_template_variant_archived: Optional[bool] = None
    external_css_list: Optional['List[ExternalCss]'] = None


LightOfferTemplateVersion.model_rebuild()



from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional
from pianosdk.anon.models.resource import Resource
from typing import List


class PasswordlessPurchaseCompleteResult(BaseModel):
    oid: Optional[str] = None
    url: Optional[str] = None
    resource: Optional['Resource'] = None
    show_offer_params: Optional[str] = None
    type: Optional[str] = None
    process_id: Optional[str] = None
    polling_enabled: Optional[bool] = None
    polling_timeouts: Optional[List[int]] = None


PasswordlessPurchaseCompleteResult.model_rebuild()



from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional


class ConsentModel(BaseModel):
    consent_pub_id: Optional[str] = None
    display_text: Optional[str] = None
    field_name: Optional[str] = None
    field_id: Optional[str] = None
    sort_order: Optional[str] = None
    checked: Optional[str] = None


ConsentModel.model_rebuild()



from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional
from pianosdk.publisher.models.template_counter_model import TemplateCounterModel
from typing import List


class CategoriesCounterModel(BaseModel):
    section: Optional[str] = None
    template_count: Optional[str] = None
    categories: Optional['List[TemplateCounterModel]'] = None


CategoriesCounterModel.model_rebuild()



from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional
from pianosdk.publisher.models.country import Country
from pianosdk.publisher.models.region import Region


class UserAddress(BaseModel):
    user_address_id: Optional[str] = None
    region: Optional['Region'] = None
    country: Optional['Country'] = None
    city: Optional[str] = None
    postal_code: Optional[str] = None
    company_name: Optional[str] = None
    first_name: Optional[str] = None
    last_name: Optional[str] = None
    personal_name: Optional[str] = None
    address1: Optional[str] = None
    address2: Optional[str] = None
    phone: Optional[str] = None
    additional_fields: Optional[str] = None


UserAddress.model_rebuild()



from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional
from pianosdk.publisher.models.term import Term
from typing import List


class PromotionApplicableTermContainer(BaseModel):
    terms: Optional['List[Term]'] = None


PromotionApplicableTermContainer.model_rebuild()



from pianosdk.publisher.api.publisher_adblocker_api import PublisherAdblockerApi
from pianosdk.publisher.api.publisher_app_api import PublisherAppApi
from pianosdk.publisher.api.publisher_app_api_token_api import PublisherAppApiTokenApi
from pianosdk.publisher.api.publisher_app_features_api import PublisherAppFeaturesApi
from pianosdk.publisher.api.publisher_consent_api import PublisherConsentApi
from pianosdk.publisher.api.publisher_consent_entry_api import PublisherConsentEntryApi
from pianosdk.publisher.api.publisher_conversion_api import PublisherConversionApi
from pianosdk.publisher.api.publisher_conversion_custom_api import PublisherConversionCustomApi
from pianosdk.publisher.api.publisher_conversion_data_api import PublisherConversionDataApi
from pianosdk.publisher.api.publisher_conversion_external_api import PublisherConversionExternalApi
from pianosdk.publisher.api.publisher_conversion_registration_api import PublisherConversionRegistrationApi
from pianosdk.publisher.api.publisher_export_api import PublisherExportApi
from pianosdk.publisher.api.publisher_export_create_api import PublisherExportCreateApi
from pianosdk.publisher.api.publisher_export_create_aam_api import PublisherExportCreateAamApi
from pianosdk.publisher.api.publisher_export_create_aam_monthly_api import PublisherExportCreateAamMonthlyApi
from pianosdk.publisher.api.publisher_export_create_access_report_export_api import PublisherExportCreateAccessReportExportApi
from pianosdk.publisher.api.publisher_export_create_subscription_details_report_api import PublisherExportCreateSubscriptionDetailsReportApi
from pianosdk.publisher.api.publisher_export_create_transactions_report_api import PublisherExportCreateTransactionsReportApi
from pianosdk.publisher.api.publisher_gdpr_api import PublisherGdprApi
from pianosdk.publisher.api.publisher_inquiry_api import PublisherInquiryApi
from pianosdk.publisher.api.publisher_licensing_contract_api import PublisherLicensingContractApi
from pianosdk.publisher.api.publisher_licensing_contract_domain_api import PublisherLicensingContractDomainApi
from pianosdk.publisher.api.publisher_licensing_contract_domain_contract_user_api import PublisherLicensingContractDomainContractUserApi
from pianosdk.publisher.api.publisher_licensing_contract_ip_range_api import PublisherLicensingContractIpRangeApi
from pianosdk.publisher.api.publisher_licensing_contract_periods_api import PublisherLicensingContractPeriodsApi
from pianosdk.publisher.api.publisher_licensing_contract_user_api import PublisherLicensingContractUserApi
from pianosdk.publisher.api.publisher_licensing_licensee_api import PublisherLicensingLicenseeApi
from pianosdk.publisher.api.publisher_licensing_notification_api import PublisherLicensingNotificationApi
from pianosdk.publisher.api.publisher_licensing_notification_rule_api import PublisherLicensingNotificationRuleApi
from pianosdk.publisher.api.publisher_licensing_schedule_api import PublisherLicensingScheduleApi
from pianosdk.publisher.api.publisher_licensing_schedule_contract_periods_api import PublisherLicensingScheduleContractPeriodsApi
from pianosdk.publisher.api.publisher_linked_term_api import PublisherLinkedTermApi
from pianosdk.publisher.api.publisher_linked_term_custom_field_api import PublisherLinkedTermCustomFieldApi
from pianosdk.publisher.api.publisher_offer_api import PublisherOfferApi
from pianosdk.publisher.api.publisher_offer_template_api import PublisherOfferTemplateApi
from pianosdk.publisher.api.publisher_offer_template_create_api import PublisherOfferTemplateCreateApi
from pianosdk.publisher.api.publisher_offer_template_inherited_api import PublisherOfferTemplateInheritedApi
from pianosdk.publisher.api.publisher_offer_template_update_api import PublisherOfferTemplateUpdateApi
from pianosdk.publisher.api.publisher_offer_template_variant_api import PublisherOfferTemplateVariantApi
from pianosdk.publisher.api.publisher_offer_term_api import PublisherOfferTermApi
from pianosdk.publisher.api.publisher_offer_term_offer_api import PublisherOfferTermOfferApi
from pianosdk.publisher.api.publisher_payment_api import PublisherPaymentApi
from pianosdk.publisher.api.publisher_payment_method_api import PublisherPaymentMethodApi
from pianosdk.publisher.api.publisher_payment_method_billing_address_api import PublisherPaymentMethodBillingAddressApi
from pianosdk.publisher.api.publisher_payment_method_gmo_api import PublisherPaymentMethodGmoApi
from pianosdk.publisher.api.publisher_payment_provider_configuration_api import PublisherPaymentProviderConfigurationApi
from pianosdk.publisher.api.publisher_promotion_api import PublisherPromotionApi
from pianosdk.publisher.api.publisher_promotion_code_api import PublisherPromotionCodeApi
from pianosdk.publisher.api.publisher_promotion_fixed_discount_api import PublisherPromotionFixedDiscountApi
from pianosdk.publisher.api.publisher_promotion_term_api import PublisherPromotionTermApi
from pianosdk.publisher.api.publisher_resource_api import PublisherResourceApi
from pianosdk.publisher.api.publisher_resource_bundle_api import PublisherResourceBundleApi
from pianosdk.publisher.api.publisher_resource_cross_app_api import PublisherResourceCrossAppApi
from pianosdk.publisher.api.publisher_resource_stats_api import PublisherResourceStatsApi
from pianosdk.publisher.api.publisher_resource_tag_api import PublisherResourceTagApi
from pianosdk.publisher.api.publisher_resource_user_api import PublisherResourceUserApi
from pianosdk.publisher.api.publisher_schedule_api import PublisherScheduleApi
from pianosdk.publisher.api.publisher_schedule_period_api import PublisherSchedulePeriodApi
from pianosdk.publisher.api.publisher_subscription_api import PublisherSubscriptionApi
from pianosdk.publisher.api.publisher_subscription_address_api import PublisherSubscriptionAddressApi
from pianosdk.publisher.api.publisher_subscription_cancel_api import PublisherSubscriptionCancelApi
from pianosdk.publisher.api.publisher_subscription_share_api import PublisherSubscriptionShareApi
from pianosdk.publisher.api.publisher_subscription_share_user_api import PublisherSubscriptionShareUserApi
from pianosdk.publisher.api.publisher_team_api import PublisherTeamApi
from pianosdk.publisher.api.publisher_term_api import PublisherTermApi
from pianosdk.publisher.api.publisher_term_change_api import PublisherTermChangeApi
from pianosdk.publisher.api.publisher_term_change_option_api import PublisherTermChangeOptionApi
from pianosdk.publisher.api.publisher_term_custom_api import PublisherTermCustomApi
from pianosdk.publisher.api.publisher_term_dynamic_api import PublisherTermDynamicApi
from pianosdk.publisher.api.publisher_term_external_api import PublisherTermExternalApi
from pianosdk.publisher.api.publisher_term_gift_api import PublisherTermGiftApi
from pianosdk.publisher.api.publisher_term_payment_api import PublisherTermPaymentApi
from pianosdk.publisher.api.publisher_term_registration_api import PublisherTermRegistrationApi
from pianosdk.publisher.api.publisher_term_stats_api import PublisherTermStatsApi
from pianosdk.publisher.api.publisher_test_api import PublisherTestApi
from pianosdk.publisher.api.publisher_user_api import PublisherUserApi
from pianosdk.publisher.api.publisher_user_access_api import PublisherUserAccessApi
from pianosdk.publisher.api.publisher_user_access_active_api import PublisherUserAccessActiveApi
from pianosdk.publisher.api.publisher_user_address_api import PublisherUserAddressApi
from pianosdk.publisher.api.publisher_user_app_api import PublisherUserAppApi
from pianosdk.publisher.api.publisher_user_billing_address_api import PublisherUserBillingAddressApi
from pianosdk.publisher.api.publisher_user_bulk_import_api import PublisherUserBulkImportApi
from pianosdk.publisher.api.publisher_user_email_api import PublisherUserEmailApi
from pianosdk.publisher.api.publisher_user_list_api import PublisherUserListApi
from pianosdk.publisher.api.publisher_user_note_api import PublisherUserNoteApi
from pianosdk.publisher.api.publisher_voucher_api import PublisherVoucherApi
from pianosdk.publisher.api.publisher_webhook_api import PublisherWebhookApi
from pianosdk.publisher.api.publisher_webhook_response_api import PublisherWebhookResponseApi
from pianosdk.publisher.api.publisher_webhook_settings_api import PublisherWebhookSettingsApi



from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional


class AccessPeriodStats(BaseModel):
    access_period_id: Optional[str] = None
    active_subscription_count: Optional[int] = None
    scheduled_subscription_count: Optional[int] = None


AccessPeriodStats.model_rebuild()



from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional
from typing import List


class AdvancedOptions(BaseModel):
    show_options: Optional[List[str]] = None


AdvancedOptions.model_rebuild()



from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional


class ShowOptionInChannelStats(BaseModel):
    id: Optional[str] = None
    name: Optional[str] = None
    count: Optional[int] = None


ShowOptionInChannelStats.model_rebuild()



from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional
from pianosdk.publisher.models.user_subscription_account import UserSubscriptionAccount
from typing import List


class SharedSubscription(BaseModel):
    subscription_id: Optional[str] = None
    term_id: Optional[str] = None
    uid: Optional[str] = None
    total_tokens: Optional[int] = None
    unused_tokens: Optional[int] = None
    redeemed_tokens: Optional[int] = None
    shared_accounts: Optional['List[UserSubscriptionAccount]'] = None


SharedSubscription.model_rebuild()



from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional


class BrainTreeCreateCreditCardInfoDto(BaseModel):
    braintree_client_token: Optional[str] = None
    version: Optional[str] = None
    braintree_client_key: Optional[str] = None
    authorization_amount: Optional[float] = None
    collect_cardholder_name: Optional[bool] = None


BrainTreeCreateCreditCardInfoDto.model_rebuild()



from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional
from pianosdk.publisher.models.global_template_filter_item import GlobalTemplateFilterItem


class GlobalTemplateFilter(BaseModel):
    template_status: Optional['GlobalTemplateFilterItem'] = None
    template_type: Optional['GlobalTemplateFilterItem'] = None
    use_case: Optional['GlobalTemplateFilterItem'] = None
    deployment_status: Optional['GlobalTemplateFilterItem'] = None


GlobalTemplateFilter.model_rebuild()



from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional


class TermChangeBillingOptions(BaseModel):
    value: Optional[str] = None
    name: Optional[str] = None
    prorate_disabled: Optional[bool] = None
    secure_enabled: Optional[bool] = None


TermChangeBillingOptions.model_rebuild()



from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional
from pianosdk.publisher.models.app import App
from pianosdk.publisher.models.braintree_merchant_account_id_entry import BraintreeMerchantAccountIdEntry
from pianosdk.publisher.models.payee_settings_entry import PayeeSettingsEntry
from typing import List


class BraintreeConfiguration(BaseModel):
    configuration_id: Optional[str] = None
    app: Optional['App'] = None
    source_name: Optional[str] = None
    title: Optional[str] = None
    braintree_merchant_id: Optional[str] = None
    braintree_client_key: Optional[str] = None
    braintree_merchant_accounts: Optional['List[BraintreeMerchantAccountIdEntry]'] = None
    braintree_public_key: Optional[str] = None
    braintree_private_key: Optional[str] = None
    is_disabled: Optional[bool] = None
    is_editable: Optional[bool] = None
    is_paypal_enabled: Optional[bool] = None
    is_apple_pay_enabled: Optional[bool] = None
    braintree_descriptor: Optional[str] = None
    braintree_trial_descriptor: Optional[str] = None
    braintree_app_name_custom_field: Optional[str] = None
    payee_settings: Optional['List[PayeeSettingsEntry]'] = None
    is_visible: Optional[bool] = None
    version: Optional[str] = None
    version_title: Optional[str] = None
    use_moto: Optional[bool] = None
    default_currency: Optional[str] = None
    collect_cardholder_name: Optional[bool] = None


BraintreeConfiguration.model_rebuild()



from datetime import datetime
from io import StringIO
from typing import TextIO, Dict, List, Union

from pianosdk.api_response import ApiResponse
from pianosdk.base_api import BaseApi
from pianosdk.configuration import Configuration
from pianosdk.httpwrap import HttpCallBack
from pianosdk.utils import _json_deserialize, _encode_parameter
from pianosdk.publisher.models.resource import Resource


class PublisherResourceApi(BaseApi):
    def __init__(self, config: Configuration, http_callback: HttpCallBack = None) -> None:
        super().__init__(config, http_callback)

    def attach_resource_to_fixed_bundle(self, aid: str, included_rid: List[str], bundle_rid: str) -> ApiResponse[Dict]:
        _url_path = '/api/v3/publisher/resource/attach'
        _query_url = self.config.get_base_url() + _url_path
        _query_parameters = {
            'aid': _encode_parameter(aid),
            'included_rid': _encode_parameter(included_rid),
            'bundle_rid': _encode_parameter(bundle_rid)
        }

        _headers = {
            'api_token': self.config.api_token,
            'Accept': 'application/json'
        }

        _parameters = {

        }

        _body = None
        _files = None

        _request = self.config.http_client.build_request('GET',
                                                         _query_url,
                                                         headers=_headers,
                                                         query_parameters=_query_parameters,
                                                         parameters=_parameters,
                                                         json=_body,
                                                         files=_files)
        _response = self._execute_request(_request)
        _result = _json_deserialize(_response)
        return _result

    def count(self, aid: str) -> ApiResponse[int]:
        _url_path = '/api/v3/publisher/resource/count'
        _query_url = self.config.get_base_url() + _url_path
        _query_parameters = {
            'aid': _encode_parameter(aid)
        }

        _headers = {
            'api_token': self.config.api_token,
            'Accept': 'application/json'
        }

        _parameters = {

        }

        _body = None
        _files = None

        _request = self.config.http_client.build_request('GET',
                                                         _query_url,
                                                         headers=_headers,
                                                         query_parameters=_query_parameters,
                                                         parameters=_parameters,
                                                         json=_body,
                                                         files=_files)
        _response = self._execute_request(_request)
        _result = _json_deserialize(_response, int)
        return _result

    def create_resource(self, aid: str, name: str, rid: str = None, description: str = None, type: str = 'standard', image_url: str = None, bundle_type: str = None, resource_tag_id: List[str] = None, publish_date: datetime = None, resource_url: str = None, external_id: str = None) -> ApiResponse[Resource]:
        _url_path = '/api/v3/publisher/resource/create'
        _query_url = self.config.get_base_url() + _url_path
        _query_parameters = {

        }

        _headers = {
            'api_token': self.config.api_token,
            'Accept': 'application/json'
        }

        _parameters = {
            'aid': _encode_parameter(aid),
            'rid': _encode_parameter(rid),
            'name': _encode_parameter(name),
            'description': _encode_parameter(description),
            'type': _encode_parameter(type),
            'image_url': _encode_parameter(image_url),
            'bundle_type': _encode_parameter(bundle_type),
            'resource_tag_id': _encode_parameter(resource_tag_id),
            'publish_date': _encode_parameter(publish_date),
            'resource_url': _encode_parameter(resource_url),
            'external_id': _encode_parameter(external_id)
        }

        _body = None
        _files = None

        _request = self.config.http_client.build_request('POST',
                                                         _query_url,
                                                         headers=_headers,
                                                         query_parameters=_query_parameters,
                                                         parameters=_parameters,
                                                         json=_body,
                                                         files=_files)
        _response = self._execute_request(_request)
        _result = _json_deserialize(_response, Resource)
        return _result

    def delete_resource(self, aid: str, rid: str) -> ApiResponse[Dict]:
        _url_path = '/api/v3/publisher/resource/delete'
        _query_url = self.config.get_base_url() + _url_path
        _query_parameters = {

        }

        _headers = {
            'api_token': self.config.api_token,
            'Accept': 'application/json'
        }

        _parameters = {
            'aid': _encode_parameter(aid),
            'rid': _encode_parameter(rid)
        }

        _body = None
        _files = None

        _request = self.config.http_client.build_request('POST',
                                                         _query_url,
                                                         headers=_headers,
                                                         query_parameters=_query_parameters,
                                                         parameters=_parameters,
                                                         json=_body,
                                                         files=_files)
        _response = self._execute_request(_request)
        _result = _json_deserialize(_response)
        return _result

    def detach_resource_from_fixed_bundle(self, aid: str, rid: str, bundle_rid: str) -> ApiResponse[Dict]:
        _url_path = '/api/v3/publisher/resource/detach'
        _query_url = self.config.get_base_url() + _url_path
        _query_parameters = {
            'aid': _encode_parameter(aid),
            'rid': _encode_parameter(rid),
            'bundle_rid': _encode_parameter(bundle_rid)
        }

        _headers = {
            'api_token': self.config.api_token,
            'Accept': 'application/json'
        }

        _parameters = {

        }

        _body = None
        _files = None

        _request = self.config.http_client.build_request('GET',
                                                         _query_url,
                                                         headers=_headers,
                                                         query_parameters=_query_parameters,
                                                         parameters=_parameters,
                                                         json=_body,
                                                         files=_files)
        _response = self._execute_request(_request)
        _result = _json_deserialize(_response)
        return _result

    def get_resource(self, aid: str, rid: str) -> ApiResponse[Resource]:
        _url_path = '/api/v3/publisher/resource/get'
        _query_url = self.config.get_base_url() + _url_path
        _query_parameters = {
            'aid': _encode_parameter(aid),
            'rid': _encode_parameter(rid)
        }

        _headers = {
            'api_token': self.config.api_token,
            'Accept': 'application/json'
        }

        _parameters = {

        }

        _body = None
        _files = None

        _request = self.config.http_client.build_request('GET',
                                                         _query_url,
                                                         headers=_headers,
                                                         query_parameters=_query_parameters,
                                                         parameters=_parameters,
                                                         json=_body,
                                                         files=_files)
        _response = self._execute_request(_request)
        _result = _json_deserialize(_response, Resource)
        return _result

    def list_bundles(self, aid: str, rid: str, offset: int = 0, limit: int = 25, order_direction: str = 'asc', order_by: str = 'name', bundle_type: List[int] = None) -> ApiResponse[List[Resource]]:
        _url_path = '/api/v3/publisher/resource/bundles'
        _query_url = self.config.get_base_url() + _url_path
        _query_parameters = {
            'aid': _encode_parameter(aid),
            'rid': _encode_parameter(rid),
            'offset': _encode_parameter(offset),
            'limit': _encode_parameter(limit),
            'order_by': _encode_parameter(order_by),
            'order_direction': _encode_parameter(order_direction),
            'bundle_type': _encode_parameter(bundle_type)
        }

        _headers = {
            'api_token': self.config.api_token,
            'Accept': 'application/json'
        }

        _parameters = {

        }

        _body = None
        _files = None

        _request = self.config.http_client.build_request('GET',
                                                         _query_url,
                                                         headers=_headers,
                                                         query_parameters=_query_parameters,
                                                         parameters=_parameters,
                                                         json=_body,
                                                         files=_files)
        _response = self._execute_request(_request)
        _result = _json_deserialize(_response, Resource)
        return _result

    def list_resources(self, aid: str, offset: int = 0, limit: int = 25, type: str = 'NA', order_direction: str = 'asc', order_by: str = 'name', included_tag_id: List[str] = None, excluded_rid: List[str] = None, included_rid: List[str] = None, q: str = None, disabled: bool = False, bundle_type: int = None) -> ApiResponse[List[Resource]]:
        _url_path = '/api/v3/publisher/resource/list'
        _query_url = self.config.get_base_url() + _url_path
        _query_parameters = {
            'aid': _encode_parameter(aid),
            'included_tag_id': _encode_parameter(included_tag_id),
            'excluded_rid': _encode_parameter(excluded_rid),
            'included_rid': _encode_parameter(included_rid),
            'q': _encode_parameter(q),
            'offset': _encode_parameter(offset),
            'limit': _encode_parameter(limit),
            'order_by': _encode_parameter(order_by),
            'order_direction': _encode_parameter(order_direction),
            'disabled': _encode_parameter(disabled),
            'type': _encode_parameter(type),
            'bundle_type': _encode_parameter(bundle_type)
        }

        _headers = {
            'api_token': self.config.api_token,
            'Accept': 'application/json'
        }

        _parameters = {

        }

        _body = None
        _files = None

        _request = self.config.http_client.build_request('GET',
                                                         _query_url,
                                                         headers=_headers,
                                                         query_parameters=_query_parameters,
                                                         parameters=_parameters,
                                                         json=_body,
                                                         files=_files)
        _response = self._execute_request(_request)
        _result = _json_deserialize(_response, Resource)
        return _result

    def update_resource(self, aid: str, rid: str, name: str = None, new_rid: str = None, image_url: str = None, description: str = None, disabled: bool = None, publish_date: datetime = None, included_rid: List[str] = None, fixed_bundle_rid: List[str] = None, add_term_id: List[str] = None, del_term_id: List[str] = None, included_tag_id: List[str] = None, included_tag_name: List[str] = None, resource_url: str = None, external_id: str = None, is_fbia_resource: bool = None) -> ApiResponse[Resource]:
        _url_path = '/api/v3/publisher/resource/update'
        _query_url = self.config.get_base_url() + _url_path
        _query_parameters = {

        }

        _headers = {
            'api_token': self.config.api_token,
            'Accept': 'application/json'
        }

        _parameters = {
            'aid': _encode_parameter(aid),
            'rid': _encode_parameter(rid),
            'name': _encode_parameter(name),
            'new_rid': _encode_parameter(new_rid),
            'image_url': _encode_parameter(image_url),
            'description': _encode_parameter(description),
            'disabled': _encode_parameter(disabled),
            'publish_date': _encode_parameter(publish_date),
            'included_rid': _encode_parameter(included_rid),
            'fixed_bundle_rid': _encode_parameter(fixed_bundle_rid),
            'add_term_id': _encode_parameter(add_term_id),
            'del_term_id': _encode_parameter(del_term_id),
            'included_tag_id': _encode_parameter(included_tag_id),
            'included_tag_name': _encode_parameter(included_tag_name),
            'resource_url': _encode_parameter(resource_url),
            'external_id': _encode_parameter(external_id),
            'is_fbia_resource': _encode_parameter(is_fbia_resource)
        }

        _body = None
        _files = None

        _request = self.config.http_client.build_request('POST',
                                                         _query_url,
                                                         headers=_headers,
                                                         query_parameters=_query_parameters,
                                                         parameters=_parameters,
                                                         json=_body,
                                                         files=_files)
        _response = self._execute_request(_request)
        _result = _json_deserialize(_response, Resource)
        return _result




from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional
from pianosdk.publisher.models.term import Term
from pianosdk.publisher.models.term_conversion_subscription import TermConversionSubscription


class UserPaymentDTO(BaseModel):
    user_payment_id: Optional[str] = None
    create_date: Optional[str] = None
    user_payment_state: Optional[str] = None
    renewal: Optional[bool] = None
    amount: Optional[float] = None
    price: Optional[str] = None
    currency: Optional[str] = None
    refundable: Optional[bool] = None
    subscription: Optional['TermConversionSubscription'] = None
    term: Optional['Term'] = None
    tax: Optional[float] = None
    tax_billing_plan: Optional[str] = None
    payment_method: Optional[str] = None
    upi_ext_customer_id: Optional[str] = None
    upi_ext_customer_id_label: Optional[str] = None
    external_transaction_id: Optional[str] = None
    tracking_id: Optional[str] = None
    original_price: Optional[str] = None


UserPaymentDTO.model_rebuild()



from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional
from pianosdk.publisher.models.duration import Duration


class CreateAccessPeriodParams(BaseModel):
    name: Optional[str] = None
    type: Optional[str] = None
    access_end_date: Optional[date] = None
    total_iterations: Optional[int] = None
    duration: Optional['Duration'] = None
    amount: Optional[float] = None
    billing_type: Optional[str] = None
    billing_duration: Optional['Duration'] = None
    billing_day: Optional[int] = None
    billing_month: Optional[int] = None
    subscription_cancellation_allowed: Optional[bool] = None


CreateAccessPeriodParams.model_rebuild()



from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional
from pianosdk.publisher.models.light_offer import LightOffer
from typing import List


class OfferList(BaseModel):
    purchase_offers: Optional['List[LightOffer]'] = None
    upgrade_offers: Optional['List[LightOffer]'] = None


OfferList.model_rebuild()



from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional


class ExternalAPIField(BaseModel):
    field_name: Optional[str] = None
    field_title: Optional[str] = None
    description: Optional[str] = None
    mandatory: Optional[bool] = None
    hidden: Optional[bool] = None
    default_value: Optional[str] = None
    order: Optional[int] = None
    type: Optional[str] = None
    editable: Optional[str] = None


ExternalAPIField.model_rebuild()



from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional
from pianosdk.publisher.models.period_link import PeriodLink
from typing import List


class Link(BaseModel):
    term_id: Optional[str] = None
    name: Optional[str] = None
    type: Optional[str] = None
    payment_billing_plan_description: Optional[str] = None
    rid: Optional[str] = None
    resource_name: Optional[str] = None
    periods: Optional['List[PeriodLink]'] = None


Link.model_rebuild()



from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional


class Experience(BaseModel):
    experience_id: Optional[str] = None
    aid: Optional[str] = None
    type: Optional[str] = None
    cover_image_url: Optional[str] = None
    title: Optional[str] = None
    description: Optional[str] = None
    model: Optional[str] = None
    draft: Optional[str] = None
    draft_date: Optional[datetime] = None
    draft_base_version: Optional[int] = None
    create_date: Optional[datetime] = None
    create_by: Optional[str] = None
    update_date: Optional[datetime] = None
    update_by: Optional[str] = None
    version: Optional[int] = None
    schedule: Optional[str] = None
    status: Optional[str] = None
    hierarchy_type: Optional[str] = None
    parent_id: Optional[str] = None


Experience.model_rebuild()



from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional


class StripeProperties(BaseModel):
    public_key: Optional[str] = None
    account_id: Optional[str] = None
    zip_is_hidden: Optional[bool] = None
    collect_cardholder_name: Optional[bool] = None


StripeProperties.model_rebuild()



from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional


class SplitTestObject(BaseModel):
    split_test_id: Optional[str] = None
    state: Optional[str] = None


SplitTestObject.model_rebuild()



from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional


class VersionItem(BaseModel):
    name: Optional[str] = None
    description: Optional[str] = None
    aid: Optional[str] = None
    type: Optional[str] = None
    published: Optional[bool] = None
    version: Optional[int] = None
    update_date: Optional[datetime] = None


VersionItem.model_rebuild()



from pianosdk.constants import USER_AGENT
from pianosdk.configuration import Configuration
from pianosdk.httpwrap import HttpCallBack
from pianosdk.httpwrap import HttpRequest, HttpResponse


class BaseApi:
    global_headers = {
        'user-agent': USER_AGENT
    }

    def __init__(self, config: Configuration, http_callback: HttpCallBack = None):
        self._config = config
        self._http_callback = http_callback

    @property
    def config(self):
        return self._config

    @property
    def http_callback(self):
        return self._http_callback

    def _execute_request(self, request: HttpRequest) -> HttpResponse:
        if self.http_callback is not None:
            self.http_callback.on_before_request(request)
        temp = self.global_headers.copy()
        temp.update(request.headers)
        request.headers = temp

        if self.config.additional_headers is not None:
            request.headers.update(self.config.additional_headers)

        response = self.config.http_client.execute(request)

        if self.http_callback is not None:
            self.http_callback.on_after_response(response)

        return response



from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional
from typing import List


class SocialLinkingResponse(BaseModel):
    identity_social_linking_state: Optional[str] = None
    password_confirmation_available: Optional[bool] = None
    linked_social_accounts: Optional[List[str]] = None
    email: Optional[str] = None
    first_name: Optional[str] = None
    last_name: Optional[str] = None
    social_type: Optional[str] = None
    is_passwordless: Optional[bool] = None


SocialLinkingResponse.model_rebuild()



from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional


class ImportUser(BaseModel):
    email: Optional[str] = None
    first_name: Optional[str] = None
    last_name: Optional[str] = None


ImportUser.model_rebuild()



from datetime import datetime
from io import StringIO
from typing import TextIO, Dict, List, Union

from pianosdk.api_response import ApiResponse
from pianosdk.base_api import BaseApi
from pianosdk.configuration import Configuration
from pianosdk.httpwrap import HttpCallBack
from pianosdk.utils import _json_deserialize, _encode_parameter
from pianosdk.publisher.models.period import Period
from pianosdk.publisher.models.result import Result


class PublisherSchedulePeriodApi(BaseApi):
    def __init__(self, config: Configuration, http_callback: HttpCallBack = None) -> None:
        super().__init__(config, http_callback)

    def add_period(self, schedule_id: str, name: str, sell_date: datetime, begin_date: datetime, end_date: datetime) -> ApiResponse[Period]:
        _url_path = '/api/v3/publisher/schedule/period/add'
        _query_url = self.config.get_base_url() + _url_path
        _query_parameters = {

        }

        _headers = {
            'api_token': self.config.api_token,
            'Accept': 'application/json'
        }

        _parameters = {
            'schedule_id': _encode_parameter(schedule_id),
            'name': _encode_parameter(name),
            'sell_date': _encode_parameter(sell_date),
            'begin_date': _encode_parameter(begin_date),
            'end_date': _encode_parameter(end_date)
        }

        _body = None
        _files = None

        _request = self.config.http_client.build_request('POST',
                                                         _query_url,
                                                         headers=_headers,
                                                         query_parameters=_query_parameters,
                                                         parameters=_parameters,
                                                         json=_body,
                                                         files=_files)
        _response = self._execute_request(_request)
        _result = _json_deserialize(_response, Period)
        return _result

    def delete_period(self, period_id: str) -> ApiResponse[Result]:
        _url_path = '/api/v3/publisher/schedule/period/delete'
        _query_url = self.config.get_base_url() + _url_path
        _query_parameters = {

        }

        _headers = {
            'api_token': self.config.api_token,
            'Accept': 'application/json'
        }

        _parameters = {
            'period_id': _encode_parameter(period_id)
        }

        _body = None
        _files = None

        _request = self.config.http_client.build_request('POST',
                                                         _query_url,
                                                         headers=_headers,
                                                         query_parameters=_query_parameters,
                                                         parameters=_parameters,
                                                         json=_body,
                                                         files=_files)
        _response = self._execute_request(_request)
        _result = _json_deserialize(_response, Result)
        return _result

    def update_period(self, schedule_id: str, period_id: str, name: str, sell_date: datetime, begin_date: datetime, end_date: datetime) -> ApiResponse[List[Period]]:
        _url_path = '/api/v3/publisher/schedule/period/update'
        _query_url = self.config.get_base_url() + _url_path
        _query_parameters = {

        }

        _headers = {
            'api_token': self.config.api_token,
            'Accept': 'application/json'
        }

        _parameters = {
            'schedule_id': _encode_parameter(schedule_id),
            'period_id': _encode_parameter(period_id),
            'name': _encode_parameter(name),
            'sell_date': _encode_parameter(sell_date),
            'begin_date': _encode_parameter(begin_date),
            'end_date': _encode_parameter(end_date)
        }

        _body = None
        _files = None

        _request = self.config.http_client.build_request('POST',
                                                         _query_url,
                                                         headers=_headers,
                                                         query_parameters=_query_parameters,
                                                         parameters=_parameters,
                                                         json=_body,
                                                         files=_files)
        _response = self._execute_request(_request)
        _result = _json_deserialize(_response, Period)
        return _result




from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional
from pianosdk.id.models.social_linking_response import SocialLinkingResponse


class TokenResponse(BaseModel):
    access_token: Optional[str] = None
    token_type: Optional[str] = None
    refresh_token: Optional[str] = None
    code: Optional[str] = None
    error: Optional[str] = None
    error_description: Optional[str] = None
    expires_in: Optional[int] = None
    preauth_token: Optional[str] = None
    social_linking_response: Optional['SocialLinkingResponse'] = None
    registration: Optional[bool] = None
    site_cookie_domain: Optional[str] = None
    email_confirmation_required: Optional[bool] = None
    login_token_id: Optional[str] = None
    extend_expired_access_enabled: Optional[bool] = None
    direction_url: Optional[str] = None
    passwordless_token: Optional[str] = None
    pub_id: Optional[str] = None
    authorized_by_sso: Optional[bool] = None
    message: Optional[str] = None
    sso_confirmation: Optional[bool] = None
    two_factor_auth_required: Optional[bool] = None
    phone_confirmation_required: Optional[bool] = None


TokenResponse.model_rebuild()



from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional


class CountrySimpleModel(BaseModel):
    country_code: Optional[str] = None
    pub_id: Optional[str] = None


CountrySimpleModel.model_rebuild()



from datetime import datetime
from io import StringIO
from typing import TextIO, Dict, List, Union

from pianosdk.api_response import ApiResponse
from pianosdk.base_api import BaseApi
from pianosdk.configuration import Configuration
from pianosdk.httpwrap import HttpCallBack
from pianosdk.utils import _json_deserialize, _encode_parameter
from pianosdk.publisher.models.contract import Contract


class PublisherLicensingContractApi(BaseApi):
    def __init__(self, config: Configuration, http_callback: HttpCallBack = None) -> None:
        super().__init__(config, http_callback)

    def activate_contract(self, aid: str, contract_id: str) -> ApiResponse[Contract]:
        _url_path = '/api/v3/publisher/licensing/contract/activate'
        _query_url = self.config.get_base_url() + _url_path
        _query_parameters = {

        }

        _headers = {
            'api_token': self.config.api_token,
            'Accept': 'application/json'
        }

        _parameters = {
            'aid': _encode_parameter(aid),
            'contract_id': _encode_parameter(contract_id)
        }

        _body = None
        _files = None

        _request = self.config.http_client.build_request('POST',
                                                         _query_url,
                                                         headers=_headers,
                                                         query_parameters=_query_parameters,
                                                         parameters=_parameters,
                                                         json=_body,
                                                         files=_files)
        _response = self._execute_request(_request)
        _result = _json_deserialize(_response, Contract)
        return _result

    def archive_contract(self, aid: str, contract_id: str) -> ApiResponse[Dict]:
        _url_path = '/api/v3/publisher/licensing/contract/archive'
        _query_url = self.config.get_base_url() + _url_path
        _query_parameters = {

        }

        _headers = {
            'api_token': self.config.api_token,
            'Accept': 'application/json'
        }

        _parameters = {
            'aid': _encode_parameter(aid),
            'contract_id': _encode_parameter(contract_id)
        }

        _body = None
        _files = None

        _request = self.config.http_client.build_request('POST',
                                                         _query_url,
                                                         headers=_headers,
                                                         query_parameters=_query_parameters,
                                                         parameters=_parameters,
                                                         json=_body,
                                                         files=_files)
        _response = self._execute_request(_request)
        _result = _json_deserialize(_response)
        return _result

    def create_contract(self, aid: str, licensee_id: str, contract_type: str, contract_name: str, seats_number: int, is_hard_seats_limit_type: bool, rid: str, landing_page_url: str = None) -> ApiResponse[Contract]:
        _url_path = '/api/v3/publisher/licensing/contract/create'
        _query_url = self.config.get_base_url() + _url_path
        _query_parameters = {

        }

        _headers = {
            'api_token': self.config.api_token,
            'Accept': 'application/json'
        }

        _parameters = {
            'aid': _encode_parameter(aid),
            'licensee_id': _encode_parameter(licensee_id),
            'contract_type': _encode_parameter(contract_type),
            'contract_name': _encode_parameter(contract_name),
            'seats_number': _encode_parameter(seats_number),
            'is_hard_seats_limit_type': _encode_parameter(is_hard_seats_limit_type),
            'rid': _encode_parameter(rid),
            'landing_page_url': _encode_parameter(landing_page_url)
        }

        _body = None
        _files = None

        _request = self.config.http_client.build_request('POST',
                                                         _query_url,
                                                         headers=_headers,
                                                         query_parameters=_query_parameters,
                                                         parameters=_parameters,
                                                         json=_body,
                                                         files=_files)
        _response = self._execute_request(_request)
        _result = _json_deserialize(_response, Contract)
        return _result

    def deactivate_contract(self, aid: str, contract_id: str) -> ApiResponse[Contract]:
        _url_path = '/api/v3/publisher/licensing/contract/deactivate'
        _query_url = self.config.get_base_url() + _url_path
        _query_parameters = {

        }

        _headers = {
            'api_token': self.config.api_token,
            'Accept': 'application/json'
        }

        _parameters = {
            'aid': _encode_parameter(aid),
            'contract_id': _encode_parameter(contract_id)
        }

        _body = None
        _files = None

        _request = self.config.http_client.build_request('POST',
                                                         _query_url,
                                                         headers=_headers,
                                                         query_parameters=_query_parameters,
                                                         parameters=_parameters,
                                                         json=_body,
                                                         files=_files)
        _response = self._execute_request(_request)
        _result = _json_deserialize(_response, Contract)
        return _result

    def get_contract(self, aid: str, contract_id: str) -> ApiResponse[Contract]:
        _url_path = '/api/v3/publisher/licensing/contract/get'
        _query_url = self.config.get_base_url() + _url_path
        _query_parameters = {
            'aid': _encode_parameter(aid),
            'contract_id': _encode_parameter(contract_id)
        }

        _headers = {
            'api_token': self.config.api_token,
            'Accept': 'application/json'
        }

        _parameters = {

        }

        _body = None
        _files = None

        _request = self.config.http_client.build_request('GET',
                                                         _query_url,
                                                         headers=_headers,
                                                         query_parameters=_query_parameters,
                                                         parameters=_parameters,
                                                         json=_body,
                                                         files=_files)
        _response = self._execute_request(_request)
        _result = _json_deserialize(_response, Contract)
        return _result

    def get_contract_list(self, aid: str, licensee_id: str, offset: int = 0, limit: int = 100, q: str = None) -> ApiResponse[List[Contract]]:
        _url_path = '/api/v3/publisher/licensing/contract/list'
        _query_url = self.config.get_base_url() + _url_path
        _query_parameters = {
            'aid': _encode_parameter(aid),
            'licensee_id': _encode_parameter(licensee_id),
            'q': _encode_parameter(q),
            'offset': _encode_parameter(offset),
            'limit': _encode_parameter(limit)
        }

        _headers = {
            'api_token': self.config.api_token,
            'Accept': 'application/json'
        }

        _parameters = {

        }

        _body = None
        _files = None

        _request = self.config.http_client.build_request('GET',
                                                         _query_url,
                                                         headers=_headers,
                                                         query_parameters=_query_parameters,
                                                         parameters=_parameters,
                                                         json=_body,
                                                         files=_files)
        _response = self._execute_request(_request)
        _result = _json_deserialize(_response, Contract)
        return _result

    def redeem_contract(self, aid: str, contract_id: str, uid: str) -> ApiResponse[str]:
        _url_path = '/api/v3/publisher/licensing/contract/redeem'
        _query_url = self.config.get_base_url() + _url_path
        _query_parameters = {

        }

        _headers = {
            'api_token': self.config.api_token,
            'Accept': 'application/json'
        }

        _parameters = {
            'aid': _encode_parameter(aid),
            'contract_id': _encode_parameter(contract_id),
            'uid': _encode_parameter(uid)
        }

        _body = None
        _files = None

        _request = self.config.http_client.build_request('POST',
                                                         _query_url,
                                                         headers=_headers,
                                                         query_parameters=_query_parameters,
                                                         parameters=_parameters,
                                                         json=_body,
                                                         files=_files)
        _response = self._execute_request(_request)
        _result = _json_deserialize(_response, str)
        return _result

    def update_contract(self, aid: str, licensee_id: str, contract_type: str, contract_id: str, contract_name: str, seats_number: int, is_hard_seats_limit_type: bool, rid: str, landing_page_url: str, contract_description: str = None, schedule_id: str = None) -> ApiResponse[Contract]:
        _url_path = '/api/v3/publisher/licensing/contract/update'
        _query_url = self.config.get_base_url() + _url_path
        _query_parameters = {

        }

        _headers = {
            'api_token': self.config.api_token,
            'Accept': 'application/json'
        }

        _parameters = {
            'aid': _encode_parameter(aid),
            'licensee_id': _encode_parameter(licensee_id),
            'contract_type': _encode_parameter(contract_type),
            'contract_id': _encode_parameter(contract_id),
            'contract_name': _encode_parameter(contract_name),
            'contract_description': _encode_parameter(contract_description),
            'seats_number': _encode_parameter(seats_number),
            'is_hard_seats_limit_type': _encode_parameter(is_hard_seats_limit_type),
            'rid': _encode_parameter(rid),
            'landing_page_url': _encode_parameter(landing_page_url),
            'schedule_id': _encode_parameter(schedule_id)
        }

        _body = None
        _files = None

        _request = self.config.http_client.build_request('POST',
                                                         _query_url,
                                                         headers=_headers,
                                                         query_parameters=_query_parameters,
                                                         parameters=_parameters,
                                                         json=_body,
                                                         files=_files)
        _response = self._execute_request(_request)
        _result = _json_deserialize(_response, Contract)
        return _result




from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional
from pianosdk.publisher.models.locale_model import LocaleModel
from typing import List


class LanguageModel(BaseModel):
    language_name: Optional[str] = None
    label: Optional[str] = None
    localized_label: Optional[str] = None
    locales: Optional['List[LocaleModel]'] = None


LanguageModel.model_rebuild()



from datetime import datetime
from io import StringIO
from typing import TextIO, Dict, List, Union

from pianosdk.api_response import ApiResponse
from pianosdk.base_api import BaseApi
from pianosdk.configuration import Configuration
from pianosdk.httpwrap import HttpCallBack
from pianosdk.utils import _json_deserialize, _encode_parameter
from pianosdk.publisher.models.user_payment_info import UserPaymentInfo


class PublisherPaymentMethodApi(BaseApi):
    def __init__(self, config: Configuration, http_callback: HttpCallBack = None) -> None:
        super().__init__(config, http_callback)

    def create_payment_instrument(self, aid: str, uid: str, token: str, source_id: int, set_as_default: bool = None, user_billing_address: str = None, expiration_month: int = None, expiration_year: int = None, last_four_digits: str = None, additional_info: str = None, issuer_country: str = None) -> ApiResponse[str]:
        _url_path = '/api/v3/publisher/payment/method/add'
        _query_url = self.config.get_base_url() + _url_path
        _query_parameters = {

        }

        _headers = {
            'api_token': self.config.api_token,
            'Accept': 'application/json'
        }

        _parameters = {
            'aid': _encode_parameter(aid),
            'uid': _encode_parameter(uid),
            'token': _encode_parameter(token),
            'set_as_default': _encode_parameter(set_as_default),
            'user_billing_address': _encode_parameter(user_billing_address),
            'expiration_month': _encode_parameter(expiration_month),
            'expiration_year': _encode_parameter(expiration_year),
            'last_four_digits': _encode_parameter(last_four_digits),
            'additional_info': _encode_parameter(additional_info),
            'issuer_country': _encode_parameter(issuer_country),
            'source_id': _encode_parameter(source_id)
        }

        _body = None
        _files = None

        _request = self.config.http_client.build_request('POST',
                                                         _query_url,
                                                         headers=_headers,
                                                         query_parameters=_query_parameters,
                                                         parameters=_parameters,
                                                         json=_body,
                                                         files=_files)
        _response = self._execute_request(_request)
        _result = _json_deserialize(_response, str)
        return _result

    def delete_payment_instrument(self, aid: str, uid: str, payment_method_id: str) -> ApiResponse[bool]:
        _url_path = '/api/v3/publisher/payment/method/remove'
        _query_url = self.config.get_base_url() + _url_path
        _query_parameters = {

        }

        _headers = {
            'api_token': self.config.api_token,
            'Accept': 'application/json'
        }

        _parameters = {
            'aid': _encode_parameter(aid),
            'uid': _encode_parameter(uid),
            'payment_method_id': _encode_parameter(payment_method_id)
        }

        _body = None
        _files = None

        _request = self.config.http_client.build_request('POST',
                                                         _query_url,
                                                         headers=_headers,
                                                         query_parameters=_query_parameters,
                                                         parameters=_parameters,
                                                         json=_body,
                                                         files=_files)
        _response = self._execute_request(_request)
        _result = _json_deserialize(_response, bool)
        return _result

    def get_user_payment_info(self, aid: str, uid: str, user_payment_info_id: str) -> ApiResponse[UserPaymentInfo]:
        _url_path = '/api/v3/publisher/payment/method/get'
        _query_url = self.config.get_base_url() + _url_path
        _query_parameters = {
            'aid': _encode_parameter(aid),
            'uid': _encode_parameter(uid),
            'user_payment_info_id': _encode_parameter(user_payment_info_id)
        }

        _headers = {
            'api_token': self.config.api_token,
            'Accept': 'application/json'
        }

        _parameters = {

        }

        _body = None
        _files = None

        _request = self.config.http_client.build_request('GET',
                                                         _query_url,
                                                         headers=_headers,
                                                         query_parameters=_query_parameters,
                                                         parameters=_parameters,
                                                         json=_body,
                                                         files=_files)
        _response = self._execute_request(_request)
        _result = _json_deserialize(_response, UserPaymentInfo)
        return _result

    def update_payment_instrument(self, aid: str, uid: str, token: str = None, set_as_default: bool = None, user_billing_address: str = None, expiration_month: int = None, expiration_year: int = None, last_four_digits: str = None, additional_info: str = None, issuer_country: str = None, payment_method_id: str = None) -> ApiResponse[str]:
        _url_path = '/api/v3/publisher/payment/method/update'
        _query_url = self.config.get_base_url() + _url_path
        _query_parameters = {

        }

        _headers = {
            'api_token': self.config.api_token,
            'Accept': 'application/json'
        }

        _parameters = {
            'aid': _encode_parameter(aid),
            'uid': _encode_parameter(uid),
            'token': _encode_parameter(token),
            'set_as_default': _encode_parameter(set_as_default),
            'user_billing_address': _encode_parameter(user_billing_address),
            'expiration_month': _encode_parameter(expiration_month),
            'expiration_year': _encode_parameter(expiration_year),
            'last_four_digits': _encode_parameter(last_four_digits),
            'additional_info': _encode_parameter(additional_info),
            'issuer_country': _encode_parameter(issuer_country),
            'payment_method_id': _encode_parameter(payment_method_id)
        }

        _body = None
        _files = None

        _request = self.config.http_client.build_request('POST',
                                                         _query_url,
                                                         headers=_headers,
                                                         query_parameters=_query_parameters,
                                                         parameters=_parameters,
                                                         json=_body,
                                                         files=_files)
        _response = self._execute_request(_request)
        _result = _json_deserialize(_response, str)
        return _result




from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional


class VariantItem(BaseModel):
    name: Optional[str] = None
    update_date: Optional[int] = None


VariantItem.model_rebuild()



from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional


class ExternalAPIPropertySchema(BaseModel):
    field_name: Optional[str] = None
    title: Optional[str] = None
    description: Optional[str] = None


ExternalAPIPropertySchema.model_rebuild()



from pianosdk.id.models.consent_model import ConsentModel
from pianosdk.id.models.custom_field_attribute_dto import CustomFieldAttributeDto
from pianosdk.id.models.custom_field_definition_dto import CustomFieldDefinitionDto
from pianosdk.id.models.custom_field_value_dto import CustomFieldValueDto
from pianosdk.id.models.import_cf_result import ImportCFResult
from pianosdk.id.models.input_stream import InputStream
from pianosdk.id.models.logout_response import LogoutResponse
from pianosdk.id.models.o_auth_request import OAuthRequest
from pianosdk.id.models.publisher_custom_field_response import PublisherCustomFieldResponse
from pianosdk.id.models.publisher_login_request import PublisherLoginRequest
from pianosdk.id.models.publisher_password_request import PublisherPasswordRequest
from pianosdk.id.models.publisher_register_request import PublisherRegisterRequest
from pianosdk.id.models.publisher_set_password_request import PublisherSetPasswordRequest
from pianosdk.id.models.publisher_user_profile_response import PublisherUserProfileResponse
from pianosdk.id.models.social_additional_input_request import SocialAdditionalInputRequest
from pianosdk.id.models.social_link_response import SocialLinkResponse
from pianosdk.id.models.social_linking_response import SocialLinkingResponse
from pianosdk.id.models.token_response import TokenResponse
from pianosdk.id.models.tooltip import Tooltip
from pianosdk.id.models.validator import Validator



from datetime import datetime
from io import StringIO
from typing import TextIO, Dict, List, Union

from pianosdk.api_response import ApiResponse
from pianosdk.base_api import BaseApi
from pianosdk.configuration import Configuration
from pianosdk.httpwrap import HttpCallBack
from pianosdk.utils import _json_deserialize, _encode_parameter
from pianosdk.publisher.models.term import Term


class PublisherTermPaymentApi(BaseApi):
    def __init__(self, config: Configuration, http_callback: HttpCallBack = None) -> None:
        super().__init__(config, http_callback)

    def create_payment_term(self, aid: str, rid: str, name: str, payment_billing_plan: str = None, payment_allow_renew_days: int = None, payment_force_auto_renew: bool = False, payment_new_customers_only: bool = True, payment_trial_new_customers_only: bool = True, payment_allow_promo_codes: bool = True, payment_renew_grace_period: int = None, payment_allow_gift: bool = False, description: str = None, product_category: str = None, verify_on_renewal: bool = False, evt_verification_period: int = None, schedule_id: str = None, schedule_billing_model: str = None, term_billing_descriptor: str = None, shared_account_count: int = None, shared_redemption_url: str = None, churn_prevention_logic_id: str = None, allow_start_in_future: bool = None, maximum_days_in_advance: int = None, collect_address: bool = None, delivery_zone: List[str] = None, default_country: str = None) -> ApiResponse[Term]:
        _url_path = '/api/v3/publisher/term/payment/create'
        _query_url = self.config.get_base_url() + _url_path
        _query_parameters = {

        }

        _headers = {
            'api_token': self.config.api_token,
            'Accept': 'application/json'
        }

        _parameters = {
            'aid': _encode_parameter(aid),
            'rid': _encode_parameter(rid),
            'name': _encode_parameter(name),
            'payment_billing_plan': _encode_parameter(payment_billing_plan),
            'payment_allow_renew_days': _encode_parameter(payment_allow_renew_days),
            'payment_force_auto_renew': _encode_parameter(payment_force_auto_renew),
            'payment_new_customers_only': _encode_parameter(payment_new_customers_only),
            'payment_trial_new_customers_only': _encode_parameter(payment_trial_new_customers_only),
            'payment_allow_promo_codes': _encode_parameter(payment_allow_promo_codes),
            'payment_renew_grace_period': _encode_parameter(payment_renew_grace_period),
            'payment_allow_gift': _encode_parameter(payment_allow_gift),
            'description': _encode_parameter(description),
            'product_category': _encode_parameter(product_category),
            'verify_on_renewal': _encode_parameter(verify_on_renewal),
            'evt_verification_period': _encode_parameter(evt_verification_period),
            'schedule_id': _encode_parameter(schedule_id),
            'schedule_billing_model': _encode_parameter(schedule_billing_model),
            'term_billing_descriptor': _encode_parameter(term_billing_descriptor),
            'shared_account_count': _encode_parameter(shared_account_count),
            'shared_redemption_url': _encode_parameter(shared_redemption_url),
            'churn_prevention_logic_id': _encode_parameter(churn_prevention_logic_id),
            'allow_start_in_future': _encode_parameter(allow_start_in_future),
            'maximum_days_in_advance': _encode_parameter(maximum_days_in_advance),
            'collect_address': _encode_parameter(collect_address),
            'delivery_zone': _encode_parameter(delivery_zone),
            'default_country': _encode_parameter(default_country)
        }

        _body = None
        _files = None

        _request = self.config.http_client.build_request('POST',
                                                         _query_url,
                                                         headers=_headers,
                                                         query_parameters=_query_parameters,
                                                         parameters=_parameters,
                                                         json=_body,
                                                         files=_files)
        _response = self._execute_request(_request)
        _result = _json_deserialize(_response, Term)
        return _result

    def update_payment_term(self, term_id: str, rid: str = None, name: str = None, payment_billing_plan: str = None, payment_allow_renew_days: int = None, payment_force_auto_renew: bool = None, payment_new_customers_only: bool = None, payment_trial_new_customers_only: bool = None, payment_allow_promo_codes: bool = None, payment_renew_grace_period: int = None, payment_allow_gift: bool = None, description: str = None, product_category: str = None, verify_on_renewal: bool = None, evt_verification_period: int = None, schedule_id: str = None, schedule_billing_model: str = None, change_options: List[str] = None, term_billing_descriptor: str = None, external_api_id: str = None, shared_account_count: int = None, shared_redemption_url: str = None, churn_prevention_logic_id: str = None, allow_start_in_future: bool = None, maximum_days_in_advance: int = None, collect_address: bool = None, delivery_zone: List[str] = None, default_country: str = None) -> ApiResponse[Term]:
        _url_path = '/api/v3/publisher/term/payment/update'
        _query_url = self.config.get_base_url() + _url_path
        _query_parameters = {

        }

        _headers = {
            'api_token': self.config.api_token,
            'Accept': 'application/json'
        }

        _parameters = {
            'term_id': _encode_parameter(term_id),
            'rid': _encode_parameter(rid),
            'name': _encode_parameter(name),
            'payment_billing_plan': _encode_parameter(payment_billing_plan),
            'payment_allow_renew_days': _encode_parameter(payment_allow_renew_days),
            'payment_force_auto_renew': _encode_parameter(payment_force_auto_renew),
            'payment_new_customers_only': _encode_parameter(payment_new_customers_only),
            'payment_trial_new_customers_only': _encode_parameter(payment_trial_new_customers_only),
            'payment_allow_promo_codes': _encode_parameter(payment_allow_promo_codes),
            'payment_renew_grace_period': _encode_parameter(payment_renew_grace_period),
            'payment_allow_gift': _encode_parameter(payment_allow_gift),
            'description': _encode_parameter(description),
            'product_category': _encode_parameter(product_category),
            'verify_on_renewal': _encode_parameter(verify_on_renewal),
            'evt_verification_period': _encode_parameter(evt_verification_period),
            'schedule_id': _encode_parameter(schedule_id),
            'schedule_billing_model': _encode_parameter(schedule_billing_model),
            'change_options': _encode_parameter(change_options),
            'term_billing_descriptor': _encode_parameter(term_billing_descriptor),
            'external_api_id': _encode_parameter(external_api_id),
            'shared_account_count': _encode_parameter(shared_account_count),
            'shared_redemption_url': _encode_parameter(shared_redemption_url),
            'churn_prevention_logic_id': _encode_parameter(churn_prevention_logic_id),
            'allow_start_in_future': _encode_parameter(allow_start_in_future),
            'maximum_days_in_advance': _encode_parameter(maximum_days_in_advance),
            'collect_address': _encode_parameter(collect_address),
            'delivery_zone': _encode_parameter(delivery_zone),
            'default_country': _encode_parameter(default_country)
        }

        _body = None
        _files = None

        _request = self.config.http_client.build_request('POST',
                                                         _query_url,
                                                         headers=_headers,
                                                         query_parameters=_query_parameters,
                                                         parameters=_parameters,
                                                         json=_body,
                                                         files=_files)
        _response = self._execute_request(_request)
        _result = _json_deserialize(_response, Term)
        return _result




from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional


class LinkedTermCheckoutTrackParams(BaseModel):
    aid: Optional[str] = None
    browser_id: Optional[str] = None
    external_term_id: Optional[str] = None
    checkout_start_date: Optional[int] = None


LinkedTermCheckoutTrackParams.model_rebuild()



from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional
from pianosdk.anon.models.linked_term_page_view_content_params import LinkedTermPageViewContentParams


class LinkedTermSessionParams(BaseModel):
    tracking_id: Optional[str] = None
    tbc: Optional[str] = None
    pcid: Optional[str] = None
    offer_id: Optional[str] = None
    offer_template_id: Optional[str] = None
    offer_template_version_id: Optional[str] = None
    page_view_id: Optional[str] = None
    page_view_content: Optional['LinkedTermPageViewContentParams'] = None
    consents: Optional[str] = None
    previous_user_segments: Optional[str] = None
    user_state: Optional[str] = None


LinkedTermSessionParams.model_rebuild()



from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional


class ContractDomain(BaseModel):
    contract_domain_value: Optional[str] = None
    contract_domain_id: Optional[str] = None
    status: Optional[str] = None
    contract_users_count: Optional[int] = None
    active_contract_users_count: Optional[int] = None


ContractDomain.model_rebuild()



from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional


class LicenseeNotification(BaseModel):
    notification_id: Optional[str] = None
    licensee_id: Optional[str] = None
    contract_id: Optional[str] = None
    message: Optional[str] = None
    parameter: Optional[str] = None
    condition: Optional[str] = None
    condition_value: Optional[int] = None
    create_date: Optional[datetime] = None


LicenseeNotification.model_rebuild()



from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional
from pianosdk.publisher.models.term import Term


class SubscriptionLogItem(BaseModel):
    subscription_id: Optional[str] = None
    email: Optional[str] = None
    uid: Optional[str] = None
    rid: Optional[str] = None
    term: Optional['Term'] = None
    billing_plan: Optional[str] = None
    start_date: Optional[datetime] = None
    next_bill_date: Optional[datetime] = None
    status_name_in_reports: Optional[str] = None
    child_access: Optional[str] = None


SubscriptionLogItem.model_rebuild()



from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional


class BulkUserImportProcessingRequestDto(BaseModel):
    bulk_user_import_id: Optional[str] = None
    bulk_user_import_created: Optional[datetime] = None
    bulk_user_import_total_user_count: Optional[int] = None
    bulk_user_import_processed_user_count: Optional[int] = None


BulkUserImportProcessingRequestDto.model_rebuild()
